# trame: simple, powerful, innovative

**trame** - a web framework that weaves together open source components into customized visual analytics easily.

**trame** is French for
- the core that ties things together
- a guide providing the essence of a task

![Welcome to trame and 3D visualization](https://kitware.github.io/trame/examples/MultiFilter.jpg)

With **trame**, create stunning, interactive web applications compactly and intuitively.

<p float="left">
  <img src="https://kitware.github.io/trame/examples/CarotidFlow.jpg" width="250" />
  <img src="https://kitware.github.io/trame/examples/UberPickupsNYC.jpg" width="250" />
  <img src="https://kitware.github.io/trame/examples/FiniteElementAnalysis.jpg" width="250" />
</p>

## 3D Visualization

VTK and ParaView are first-class citizens at the core of **trame**, providing complete control of 3D visualizations and data movement. The developers enjoy a write-once environment while trame simply exposes both local and remote rendering through a single method.

With best-in-class VTK and ParaView platforms at its core, **trame** provides complete control of 3D visualizations and data movements.
Developers benefit from a write-once environment while **trame** simply exposes both local and remote rendering through a single method.

## Rich Features

**trame** leverages existing libraries and tools such as Vuetify, Altair, Vega, deck.gl, VTK, ParaView, and more, to create vivid content for visual analytics applications.

## Problem Focused

By relying simply on Python and HTML, **trame** focuses on one's data and associated analysis and visualizations while hiding the complications of web development.

## Desktop to cloud

The resulting **trame** applications act as local desktop applications or remote cloud applications both accessed through the browser.

## Community

- [WebSite](https://kitware.github.io/trame/)
- [Discussions](https://github.com/Kitware/trame/discussions)
- [Issues](https://github.com/Kitware/trame/issues)
- [RoadMap](https://github.com/Kitware/trame/projects/1)
- [Contact Us](https://www.kitware.com/contact-us/)

## Enjoying trame?

Share your experience [with a testimonial](https://github.com/Kitware/trame/issues/18) or [with a brand approval](https://github.com/Kitware/trame/issues/19).
